@@ -16,6 +16,15 @@ rss_parse <- function(doc){
     channel <- xml2::xml_find_all(doc, "rss:channel", ns = ns)
     site <- xml2::xml_find_all(doc, "rss:item", ns = ns)
 
+    categories <- function(item){
+      xx <- xml2::xml_text(xml2::xml_find_all(item, "rss:category", ns = ns))
+      if(length(xx) < 1){
+        return(FALSE)
+      } else {
+        return(TRUE)
+      }
+    }
+
     res <- suppressWarnings({tibble::tibble(
       feed_title = xml2::xml_text(xml2::xml_find_all(channel, "rss:title", ns = ns)),
       feed_link = xml2::xml_text(xml2::xml_find_all(channel, "rss:link", ns = ns)),
@@ -32,15 +41,12 @@ rss_parse <- function(doc){
       item_date =  xml2::xml_text(xml2::xml_find_first(site, "rss:date", ns = ns)) %>%
         lubridate::parse_date_time(orders = formats),
       item_subject = xml2::xml_text(xml2::xml_find_first(site, ns = ns, "rss:subject")),
-      item_category1 = xml2::xml_text(xml2::xml_find_first(site, "rss:category[1]", ns = ns)),
-      item_category2 = xml2::xml_text(xml2::xml_find_first(site, "rss:category[2]", ns = ns)),
-      item_category3 = xml2::xml_text(xml2::xml_find_first(site, "rss:category[3]", ns = ns)),
-      item_category4 = xml2::xml_text(xml2::xml_find_first(site, "rss:category[4]", ns = ns)),
-      item_category5 = xml2::xml_text(xml2::xml_find_first(site, "rss:category[5]", ns = ns)),
       item_link = xml2::xml_text(xml2::xml_find_all(site, "rss:link", ns = ns)),
       item_description = xml2::xml_text(xml2::xml_find_first(site, "rss:description", ns = ns))
     )})
 
+    if(categories(site) == TRUE) res$item_categories <- xml2::xml_find_all(site, "rss:category/..", ns = ns)
+
     res <- Filter(function(x) !all(is.na(x)), res)
 
   } else{
@@ -61,11 +67,8 @@ rss_parse <- function(doc){
       item_date_published = xml2::xml_text(xml2::xml_find_first(site, "pubDate")) %>%
         lubridate::parse_date_time(orders = formats),
       item_description = xml2::xml_text(xml2::xml_find_first(site, "description")),
-      item_category1 = xml2::xml_text(xml2::xml_find_first(site, "category[1]")),
-      item_category2 = xml2::xml_text(xml2::xml_find_first(site, "category[2]")),
-      item_category3 = xml2::xml_text(xml2::xml_find_first(site, "category[3]")),
-      item_category4 = xml2::xml_text(xml2::xml_find_first(site, "category[4]")),
-      item_category5 = xml2::xml_text(xml2::xml_find_first(site, "category[5]")),
+      item_categories = xml2::xml_find_all(site, "category/..") %>%
+        lapply(function(item) xml2::xml_text(xml2::xml_find_all(item, "category"))),
       item_link = xml2::xml_text(xml2::xml_find_first(site, "link"))
     )})
 
